PALM-meteo: palmmeteo.library.InputGatherer Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Protected Member Functions | List of all members
palmmeteo.library.InputGatherer Class Reference

## Public Member Functions
| __init__ (self, fout, varnames, nt, output_dims, dyn_levels=True, copy_attrs=[])
| add_single_lev (self, varname, it, level, data, attrs={})
| add_full (self, varname, it, data, attrs={})
| finalize (self)

## Public Attributes
| fout
| nt
| varnames
| nv
| idx_var
| output_dims
| copy_attrs
| dyn_levels
| levels
| idx_lev
| filled
| level_dimname
| extra_dims

## Protected Member Functions
| _get_level (self, level)
| _get_var (self, varname, dt, shape, attrs)
| _pprint_missing (self, data, axis, axname, keys=None)

## Detailed Description

    Helps gather input variables for the import step and check for
    completeness. Also helps handle list of vertical levels if it is not known
    in advance. Only works on identically-shaped data - use more than one
    object if you have e.g. 2D + 3D variables.

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo.library.InputGatherer.__init__ | ( |  | self,
|  |  | fout,
|  |  | varnames,
|  |  | nt,
|  |  | output_dims,
|  |  | dyn_levels = `True`,
|  |  | copy_attrs = `[]`
| ) |  |

## Member Function Documentation

## ◆ _get_level()

palmmeteo.library.InputGatherer._get_level | ( |  | self,
|  |  | level
| ) |  |
| protected

## ◆ _get_var()

palmmeteo.library.InputGatherer._get_var | ( |  | self,
|  |  | varname,
|  |  | dt,
|  |  | shape,
|  |  | attrs
| ) |  |
| protected

## ◆ _pprint_missing()

palmmeteo.library.InputGatherer._pprint_missing | ( |  | self,
|  |  | data,
|  |  | axis,
|  |  | axname,
|  |  | keys = `None`
| ) |  |
| protected

## ◆ add_full()

palmmeteo.library.InputGatherer.add_full | ( |  | self,
|  |  | varname,
|  |  | it,
|  |  | data,
|  |  | attrs = `{}`
| ) |  |

## ◆ add_single_lev()

palmmeteo.library.InputGatherer.add_single_lev | ( |  | self,
|  |  | varname,
|  |  | it,
|  |  | level,
|  |  | data,
|  |  | attrs = `{}`
| ) |  |

## ◆ finalize()

palmmeteo.library.InputGatherer.finalize | ( |  | self | ) |

## Member Data Documentation

## ◆ copy_attrs

palmmeteo.library.InputGatherer.copy_attrs

## ◆ dyn_levels

palmmeteo.library.InputGatherer.dyn_levels

## ◆ extra_dims

palmmeteo.library.InputGatherer.extra_dims

## ◆ filled

palmmeteo.library.InputGatherer.filled

## ◆ fout

palmmeteo.library.InputGatherer.fout

## ◆ idx_lev

palmmeteo.library.InputGatherer.idx_lev

## ◆ idx_var

palmmeteo.library.InputGatherer.idx_var

## ◆ level_dimname

palmmeteo.library.InputGatherer.level_dimname

## ◆ levels

palmmeteo.library.InputGatherer.levels

## ◆ nt

palmmeteo.library.InputGatherer.nt

## ◆ nv

palmmeteo.library.InputGatherer.nv

## ◆ output_dims

palmmeteo.library.InputGatherer.output_dims

## ◆ varnames

palmmeteo.library.InputGatherer.varnames

The documentation for this class was generated from the following file:

- palmmeteo/library.py